Weblate basics
==============

Project structure
------------------

Internally, each project has translations to common strings propangated across other components within it by default.
This lightens the burden of repetitive and multi version translation.
Disable it as per :ref:`component`, still producing errors for seemingly inconsistent resulting translations.
